#' Utility functions to support the NeuroAnatomy Toolbox (nat).
#' Includes functions to provide a basic make style system to update files
#' based on timestamp information, file locking and other convenience functions
#' for working with the filesystem
#' @seealso nat
#' @keywords internal
"_PACKAGE"

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
## usethis namespace: start
## usethis namespace: end
NULL
